.. _api_elem_dataelem:

Data Elements (:mod:`pydicom.dataelem`)
=======================================

.. currentmodule:: pydicom.dataelem

Representation of DICOM data elements

.. autosummary::
   :toctree: generated/

   DataElement
   DataElement_from_raw
   RawDataElement
